@@ -1,7 +1,7 @@
 /*  XFce 4 - Netload Plugin
  *    Copyright (c) 2003 Bernhard Walle <bernhard.walle@gmx.de>
  *  
- *  Id: $Id: netload.c,v 1.9 2003/10/01 19:16:03 bwalle Exp $
+ *  Id: $Id: netload.c,v 1.11 2005/01/10 13:43:01 bwalle Exp $
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -144,6 +144,8 @@ static gboolean update_monitors(t_global_monitor *global)
     double temp;
     gint i, j;
 
+    XFCE_PANEL_LOCK();
+
     get_current_netload( &(global->monitor->data), &(net[IN]), &(net[OUT]), &(net[TOT]) );
     
 
@@ -225,6 +227,8 @@ static gboolean update_monitors(t_global_monitor *global)
                 HISTSIZE_CALCULATE, buffer[IN], buffer[OUT], buffer[TOT]);
     gtk_tooltips_set_tip(tooltips, GTK_WIDGET(global->monitor->ebox), caption, NULL);
 
+    XFCE_PANEL_UNLOCK();
+
     return TRUE;
 }
 
@@ -692,12 +696,12 @@ static void monitor_set_size(Control *ctrl, int size)
         if (settings.orientation == HORIZONTAL)
         {
             gtk_widget_set_size_request(GTK_WIDGET(global->monitor->status[i]),
-                    6 + 2 * size, icon_size[size]);
+                    6 + 2 * size, icon_size[size] - 4);
         }
         else
         {
             gtk_widget_set_size_request(GTK_WIDGET(global->monitor->status[i]),
-                    icon_size[size], 6 + 2 * size);
+                    icon_size[size] - 4, 6 + 2 * size);
         }
         gtk_widget_queue_resize(GTK_WIDGET(global->monitor->status[i]));
     }
